@@ -2,7 +2,7 @@ package Text::Template::Simple::Constants;
 use strict;
 use vars qw($VERSION $OID $DID @ISA @EXPORT @EXPORT_OK %EXPORT_TAGS);
 
-$VERSION = '0.79_04';
+$VERSION = '0.79_05';
 
 # object fields
 BEGIN { $OID = -1 } # init object field id counter
@@ -61,7 +61,7 @@ use constant T_MAXID          =>   $DID;
 
 # settings
 use constant MAX_RECURSION    => 50; # recursion limit for dynamic includes
-use constant PARENT           => 'Text::Template::Simple';
+use constant PARENT           => ( __PACKAGE__ =~ m{ (.+?) ::Constants }xms );
 use constant IS_WINDOWS       => $^O eq 'MSWin32' || $^O eq 'MSWin64';
 use constant DELIM_START      => 0; # field id
 use constant DELIM_END        => 1; # field id
@@ -132,8 +132,9 @@ use constant DIGEST_MODS => qw(
    Digest::Perl::MD5
 );
 
-use constant RE_PIPE_SPLIT   => qr/ \| (?:\s+)? (PARAM|FILTER) : /xms;
+use constant RE_PIPE_SPLIT   => qr/ \| (?:\s+)? (PARAM|FILTER|SHARE) : /xms;
 use constant RE_FILTER_SPLIT => qr/ \, (?:\s+)? /xms;
+use constant RE_INVALID_CID  => qr{[^A-Za-z_0-9]}xms;
 
 use constant DISK_CACHE_MARKER => q{# This file is automatically generated by }
                                .  PARENT
@@ -258,6 +259,7 @@ BEGIN {
                         RE_PIPE_SPLIT
                         RE_FILTER_SPLIT
                         RE_NONFILE
+                        RE_INVALID_CID
                         STAT_SIZE
                         MAX_RECURSION
                         CACHE_FMODE
@@ -286,8 +288,8 @@ TODO
 
 =head1 DESCRIPTION
 
-This document describes version C<0.79_04> of C<Text::Template::Simple::Constants>
-released on C<3 May 2009>.
+This document describes version C<0.79_05> of C<Text::Template::Simple::Constants>
+released on C<2 August 2009>.
 
 B<WARNING>: This version of the module is part of a
 developer (beta) release of the distribution and it is
@@ -297,16 +299,16 @@ Constants for Text::Template::Simple.
 
 =head1 AUTHOR
 
-Burak GE<252>rsoy, E<lt>burakE<64>cpan.orgE<gt>
+Burak Gursoy <burak@cpan.org>.
 
 =head1 COPYRIGHT
 
-Copyright 2004-2009 Burak GE<252>rsoy. All rights reserved.
+Copyright 2004 - 2009 Burak Gursoy. All rights reserved.
 
 =head1 LICENSE
 
 This library is free software; you can redistribute it and/or modify 
-it under the same terms as Perl itself, either Perl version 5.8.8 or, 
+it under the same terms as Perl itself, either Perl version 5.10.0 or, 
 at your option, any later version of Perl 5 you may have available.
 
 =cut
