@@ -33,7 +33,7 @@ package Text::Template::Simple::Constants;
 use strict;
 use vars qw($VERSION $OID $DID @ISA @EXPORT @EXPORT_OK %EXPORT_TAGS);
 
-$VERSION = '0.79_04';
+$VERSION = '0.79_05';
 
 # object fields
 BEGIN { $OID = -1 } # init object field id counter
@@ -92,7 +92,7 @@ use constant T_MAXID          =>   $DID;
 
 # settings
 use constant MAX_RECURSION    => 50; # recursion limit for dynamic includes
-use constant PARENT           => 'Text::Template::Simple';
+use constant PARENT           => ( __PACKAGE__ =~ m{ (.+?) ::Constants }xms );
 use constant IS_WINDOWS       => $^O eq 'MSWin32' || $^O eq 'MSWin64';
 use constant DELIM_START      => 0; # field id
 use constant DELIM_END        => 1; # field id
@@ -163,8 +163,9 @@ use constant DIGEST_MODS => qw(
    Digest::Perl::MD5
 );
 
-use constant RE_PIPE_SPLIT   => qr/ \| (?:\s+)? (PARAM|FILTER) : /xms;
+use constant RE_PIPE_SPLIT   => qr/ \| (?:\s+)? (PARAM|FILTER|SHARE) : /xms;
 use constant RE_FILTER_SPLIT => qr/ \, (?:\s+)? /xms;
+use constant RE_INVALID_CID  => qr{[^A-Za-z_0-9]}xms;
 
 use constant DISK_CACHE_MARKER => q{# This file is automatically generated by }
                                .  PARENT
@@ -289,6 +290,7 @@ BEGIN {
                         RE_PIPE_SPLIT
                         RE_FILTER_SPLIT
                         RE_NONFILE
+                        RE_INVALID_CID
                         STAT_SIZE
                         MAX_RECURSION
                         CACHE_FMODE
@@ -309,7 +311,7 @@ use vars qw($VERSION @ISA @EXPORT @EXPORT_OK %EXPORT_TAGS);
 use Text::Template::Simple::Constants qw( :info DIGEST_MODS );
 use Carp qw( croak );
 
-$VERSION = '0.79_04';
+$VERSION = '0.79_05';
 
 BEGIN {
    if ( IS_WINDOWS ) {
@@ -336,7 +338,7 @@ BEGIN {
    %EXPORT_TAGS = (
       macro => [qw( isaref      ishref iscref                  )],
       util  => [qw( binary_mode DIGEST trim rtrim ltrim escape )],
-      debug => [qw( fatal       DEBUG  LOG                     )],
+      debug => [qw( fatal       DEBUG  LOG  L                  )],
    );
    @EXPORT_OK        = map { @{ $EXPORT_TAGS{$_} } } keys %EXPORT_TAGS;
    $EXPORT_TAGS{all} = \@EXPORT_OK;
@@ -370,7 +372,6 @@ my $lang = {
       'tts.main.init.thandler'                   => 'user_thandler parameter must be a CODE reference',
       'tts.main.init.include'                    => 'include_paths parameter must be a ARRAY reference',
       'tts.util.escape'                          => 'Missing the character to escape',
-      'tts.util.fatal'                           => '%s is not defined as an error',
       'tts.tokenizer.new.ds'                     => 'Start delimiter is missing',
       'tts.tokenizer.new.de'                     => 'End delimiter is missing',
       'tts.tokenizer.tokenize.tmp'               => 'Template string is missing',
@@ -406,28 +407,39 @@ my $lang = {
       'tts.base.examine._examine_type.extra'     => 'Type array has unknown extra fields',
       'tts.base.examine._examine_type.unknown'   => 'Unknown first argument of %s type to compile()',
       'tts.base.include._include.unknown'        => 'Unknown include type: %s',
+      'tts.base.include._interpolate.bogus_share' => 'Only SCALARs can be shared. You have tried to share a variable '
+                                                    .'type of %s named "%s". Consider converting it to a SCALAR or try '
+                                                    .'the monolith option to enable automatic variable sharing. '
+                                                    .'But please read the fine manual first',
       'tts.base.parser._internal.id'             => '_internal(): id is missing',
       'tts.base.parser._internal.rv'             => '_internal(): id is invalid',
       'tts.base.parser._parse.unbalanced'        => '%d unbalanced %s delimiter(s) in template %s',
       'tts.cache.id.generate.data'               => "Can't generate id without data!",
       'tts.cache.id._custom.data'                => "Can't generate id without data!",
    },
+   warning => {
+      'tts.base.include.dynamic.recursion'       => qq{%s Deep recursion (>=%d) detected in the included file: %s},
+   }
 };
 
-my $DEBUG = 0;  # Disabled by default
-my $DIGEST;     # Will hold digester class name.
+my $DEBUG = 0; # Disabled by default
+my $DIGEST;    # Will hold digester class name.
 
 sub isaref { $_[0] && ref($_[0]) && ref($_[0]) eq 'ARRAY' };
 sub ishref { $_[0] && ref($_[0]) && ref($_[0]) eq 'HASH'  };
 sub iscref { $_[0] && ref($_[0]) && ref($_[0]) eq 'CODE'  };
 
-sub fatal  {
-   my $ID  = shift;
-   my $str = $lang->{error}{$ID}
-             || croak sprintf( $lang->{error}{'tts.util.fatal'}, $ID );
-   croak @_ ? sprintf($str, @_) : $str;
+sub L {
+   my $type  = shift || croak "Type parameter to L() is missing";
+   my $id    = shift || croak "ID parameter ro L() is missing";
+   my @param = @_;
+   my $root  = $lang->{ $type } || croak "$type is not a valid L() type";
+   my $value = $root->{ $id }   || croak "$id is not a valid L() ID";
+   return @param ? sprintf($value, @param) : $value;
 }
 
+sub fatal { croak L( error => @_ ) }
+
 sub escape {
    my $c = shift || fatal('tts.util.escape');
    my $s = shift;
@@ -526,7 +538,7 @@ use strict;
 use vars qw($VERSION);
 use Text::Template::Simple::Dummy;
 
-$VERSION = '0.79_04';
+$VERSION = '0.79_05';
 
 sub _compile { shift; return __PACKAGE__->_object->reval(shift) }
 
@@ -556,12 +568,10 @@ package Text::Template::Simple::Cache::ID;
 use strict;
 use vars qw($VERSION);
 use overload q{""} => 'get';
-use Text::Template::Simple::Constants qw( MAX_FL );
-use Text::Template::Simple::Util      qw( DEBUG DIGEST fatal );
+use Text::Template::Simple::Constants qw( MAX_FL RE_INVALID_CID );
+use Text::Template::Simple::Util      qw( LOG DEBUG DIGEST fatal );
 
-$VERSION = '0.79_04';
-
-my $RE_INVALID = qr{[^A-Za-z_0-9]};
+$VERSION = '0.79_05';
 
 sub new {
    my $class = shift;
@@ -573,10 +583,13 @@ sub get { my $self = shift; $$self }
 sub set { my $self = shift; $$self = shift if defined $_[0]; return; }
 
 sub generate { # cache id generator
-   my $self   = shift;
-   my $data   = shift or fatal('tts.cache.id.generate.data');
-   my $custom = shift;
-   my $regex  = shift;
+   my($self, $data, $custom, $regex) = @_;
+
+   if ( ! $data ) {
+      fatal('tts.cache.id.generate.data') if ! defined $data;
+      LOG( IDGEN => "Generating ID from empty data" ) if DEBUG;
+   }
+
    $self->set(
       $custom ? $self->_custom( $data, $regex )
               : $self->DIGEST->add( $data )->hexdigest
@@ -587,12 +600,11 @@ sub generate { # cache id generator
 sub _custom {
    my $self  = shift;
    my $data  = shift or fatal('tts.cache.id._custom.data');
-   my $regex = shift || $RE_INVALID;
+   my $regex = shift || RE_INVALID_CID;
       $data  =~ s{$regex}{_}xmsg; # remove bogus characters
-   my $len   = length( $data );
-   if ( $len > MAX_FL ) { # limit file name length
-      $data = substr $data, $len - MAX_FL, MAX_FL;
-   }
+   my $len   = length $data;
+   # limit file name length
+   $data = substr $data, $len - MAX_FL, MAX_FL if $len > MAX_FL;
    return $data;
 }
 
@@ -606,7 +618,7 @@ package Text::Template::Simple::Base::Parser;
 use strict;
 use vars qw($VERSION);
 
-$VERSION = '0.79_04';
+$VERSION = '0.79_05';
 
 use Text::Template::Simple::Util      qw(:all);
 use Text::Template::Simple::Constants qw(:all);
@@ -617,15 +629,17 @@ sub _internal {
    my $self = shift;
    my $id   = shift            || fatal('tts.base.parser._internal.id');
    my $rv   = $INTERNAL{ $id } || fatal('tts.base.parser._internal.id');
+   LOG( INTERNAL => "TEMPLATE: $id" ) if DEBUG;
    return $rv;
 }
 
 sub _parse {
-   my $self     = shift;
-   my $raw      = shift;
-   my $map_keys = shift; # code sections are hash keys
-   my $cache_id = shift;
-   my $as_is    = shift; # i.e.: do not parse -> static include
+   my($self, $raw, $opt) = @_;
+
+   # $opt->
+   #      map_keys: code sections are hash keys
+   #      as_is   : i.e.: do not parse -> static include
+
    #$self->[NEEDS_OBJECT] = 0; # reset
 
    my($ds, $de) = @{ $self->[DELIMITERS] };
@@ -639,7 +653,7 @@ sub _parse {
    my $code     = '';
    my $inside   = 0;
 
-   my($mko, $mkc) = $self->_parse_mapkeys( $map_keys, $faker, $buf_hash );
+   my($mko, $mkc) = $self->_parse_mapkeys( $opt->{map_keys}, $faker, $buf_hash );
 
    LOG( RAW => $raw ) if ( DEBUG() > 3 );
 
@@ -652,10 +666,10 @@ sub _parse {
    };
 
    # little hack to convert delims into escaped delims for static inclusion
-   $raw =~ s{\Q$ds}{$ds!}xmsg if $as_is;
+   $raw =~ s{\Q$ds}{$ds!}xmsg if $opt->{as_is};
 
    # fetch and walk the tree
-   PARSER: foreach my $token ( @{ $toke->tokenize( $raw, $map_keys ) } ) {
+   PARSER: foreach my $token ( @{ $toke->tokenize( $raw, $opt->{map_keys} ) } ) {
       my($str, $id, $chomp, undef) = @{ $token };
       LOG( TOKEN => $toke->_visualize_tid($id) . " => $str" ) if DEBUG() > 1;
       next PARSER if T_DISCARD == $id;
@@ -677,7 +691,7 @@ sub _parse {
       }
 
       elsif ( T_DYNAMIC == $id || T_STATIC == $id ) {
-         $code .= $h->{capture}->( $self->_needs_object->_include($id, $str) );
+         $code .= $h->{capture}->( $self->_needs_object->_include($id, $str, $opt) );
       }
 
       elsif ( T_MAPKEY == $id ) {
@@ -707,7 +721,7 @@ sub _parse {
          $self->[FILENAME]
    ) if $inside;
 
-   return $self->_wrapper( $code, $cache_id, $faker, $map_keys, $h );
+   return $self->_wrapper( $code, $opt->{cache_id}, $faker, $opt->{map_keys}, $h );
 }
 
 sub _parse_command {
@@ -901,6 +915,7 @@ sub _set_internal_templates {
          {
             _sub_inc => '<%TYPE%>',
             _filter  => '<%FILTER%>',
+            _share   => [<%SHARE%>],
          }
       )
    ~,
@@ -991,13 +1006,12 @@ use vars qw($VERSION);
 use Text::Template::Simple::Util qw(:all);
 use Text::Template::Simple::Constants qw(:all);
 
-$VERSION = '0.79_04';
+$VERSION = '0.79_05';
 
 sub _include_no_monolith {
    # no monolith eh?
-   my $self = shift;
-   my $type = shift;
-   my $file = shift;
+   my($self, $type, $file, $opt) = @_;
+
    my $rv   =  $self->_mini_compiler(
                   $self->_internal('no_monolith') => {
                      OBJECT => $self->[FAKER_SELF],
@@ -1012,15 +1026,15 @@ sub _include_no_monolith {
 }
 
 sub _include_static {
-   my($self, $file, $text, $err) = @_;
+   my($self, $file, $text, $err, $opt) = @_;
    return $self->[MONOLITH]
         ? 'q~' . escape('~' => $text) . '~;'
-        : $self->_include_no_monolith( T_STATIC, $file )
+        : $self->_include_no_monolith( T_STATIC, $file, $opt )
         ;
 }
 
 sub _include_dynamic {
-   my($self, $file, $text, $err) = @_;
+   my($self, $file, $text, $err, $opt) = @_;
    my $rv   = '';
 
    ++$self->[INSIDE_INCLUDE];
@@ -1030,19 +1044,17 @@ sub _include_dynamic {
 
    if ( ++$self->[COUNTER_INCLUDE]{ $file } >= MAX_RECURSION ) {
       # failsafe
-      my $max   = MAX_RECURSION;
-      my $error = qq{$err Deep recursion (>=$max) detected in }
-                . qq{the included file: $file};
-      LOG( DEEP_RECURSION => $file ) if DEBUG();
-      $error = escape( '~' => $error );
       $self->[DEEP_RECURSION] = 1;
-      $rv .= "q~$error~";
+      LOG( DEEP_RECURSION => $file ) if DEBUG;
+      my $w = L( warning => 'tts.base.include.dynamic.recursion',
+                            $err, MAX_RECURSION, $file );
+      $rv .= sprintf "q~%s~", escape( '~' => $w );
    }
    else {
       # local stuff is for file name access through $0 in templates
       $rv .= $self->[MONOLITH]
            ? do { local $self->[FILENAME] = $file; $self->_parse( $text ) }
-           : $self->_include_no_monolith( T_DYNAMIC, $file )
+           : $self->_include_no_monolith( T_DYNAMIC, $file, $opt )
            ;
    }
 
@@ -1055,6 +1067,7 @@ sub _include {
    my $self       = shift;
    my $type       = shift || 0;
    my $file       = shift;
+   my $opt        = shift;
    my $is_static  = T_STATIC  == $type ? 1 : 0;
    my $is_dynamic = T_DYNAMIC == $type ? 1 : 0;
    my $known      = $is_static || $is_dynamic;
@@ -1100,7 +1113,7 @@ sub _include {
    return "q~$err $@~" if $@;
 
    my $meth = '_include_' . ($is_dynamic ? 'dynamic' : 'static');
-   return $self->$meth( $file, $text, $err);
+   return $self->$meth( $file, $text, $err, $opt );
 }
 
 sub _interpolate {
@@ -1122,6 +1135,27 @@ sub _interpolate {
 
    my $filter = $inc{FILTER} ? escape( q{'} => $inc{FILTER} ) : '';
 
+   if ( $inc{SHARE} ) {
+      my @vars = map { trim $_ } split RE_FILTER_SPLIT, $inc{SHARE};
+      my %type = qw(
+                     @   ARRAY
+                     %   HASH
+                     *   GLOB
+                     \   REFERENCE
+                  );
+      my @buf;
+      foreach my $var ( @vars ) {
+         if ( $var !~ m{ \A \$ }xms ) {
+            my($char) = $var =~ m{ \A (.) }xms;
+            my $type  = $type{ $char } || '<UNKNOWN>';
+            fatal('tts.base.include._interpolate.bogus_share', $type, $var);
+         }
+         $var =~ tr/;//d;
+         push @buf, $var;
+      }
+      $inc{SHARE} = join ',', @buf;
+   }
+
    my $rv = $self->_mini_compiler(
                $self->_internal('sub_include') => {
                   OBJECT      => $self->[FAKER_SELF],
@@ -1130,10 +1164,12 @@ sub _interpolate {
                   TYPE        => $type,
                   PARAMS      => $inc{PARAM} ? qq{[$inc{PARAM}]} : 'undef',
                   FILTER      => $filter,
+                  SHARE       => ( $inc{SHARE} ? sprintf(qq{'%s', %s}, ($inc{SHARE}) x 2) : 'undef' ),
                } => {
                   flatten => 1,
                }
             );
+
    return $rv;
 }
 
@@ -1154,7 +1190,7 @@ use vars qw($VERSION);
 use Text::Template::Simple::Util qw(:all);
 use Text::Template::Simple::Constants qw(:all);
 
-$VERSION = '0.79_04';
+$VERSION = '0.79_05';
 
 sub _examine {
    my $self   = shift;
@@ -1221,7 +1257,7 @@ use vars qw($VERSION);
 use Text::Template::Simple::Util qw(:all);
 use Text::Template::Simple::Constants qw(:all);
 
-$VERSION = '0.79_04';
+$VERSION = '0.79_05';
 
 sub _compiler { shift->[SAFE] ? COMPILER_SAFE : COMPILER }
 
@@ -1256,22 +1292,24 @@ sub _compile {
    }
 
    if ( $opt->{chkmt} ) {
-      if ( $self->[TYPE] eq 'FILE' ) {
-         $opt->{chkmt} = (stat $tmpx)[STAT_MTIME];
-      }
-      else {
-         LOG( DISABLE_MT => "Disabling chkmt. Template is not a file" )
-            if DEBUG();
-         $opt->{chkmt} = 0;
-      }
+      $opt->{chkmt} = $self->[TYPE] eq 'FILE' ? (stat $tmpx)[STAT_MTIME]
+                    : do {
+                        DEBUG && LOG(DISABLE_MT =>
+                                     "Disabling chkmt. Template is not a file");
+                        0;
+                     }
    }
 
-   LOG( COMPILE => $opt->{id} ) if defined $opt->{id} && DEBUG();
+   LOG( COMPILE => $opt->{id} ) if DEBUG && defined $opt->{id};
 
    my($CODE, $ok);
    my $cache_id = '';
 
    my $as_is = $opt->{_sub_inc} && $opt->{_sub_inc} == T_STATIC;
+   # first element is the shared names. if it's not defined, then there
+   # are no shared variables from top level
+   delete $opt->{_share}
+      if isaref($opt->{_share}) && ! defined $opt->{_share}[0];
 
    if ( $self->[CACHE] ) {
       my $method = $opt->{id};
@@ -1293,22 +1331,41 @@ sub _compile {
    $self->cache->id( $cache_id ); # if $cache_id;
    $self->[FILENAME] = $self->[TYPE] eq 'FILE' ? $tmpx : $self->cache->id;
 
+   my($shead, @sparam) = $opt->{_share} ? @{$opt->{_share}} : ();
+
+   LOG(
+      SHARED_VARS => "Adding shared variables ($shead) from a dynamic include"
+   ) if DEBUG && $shead;
+
    if ( not $ok ) {
       # we have a cache miss; parse and compile
       LOG( CACHE_MISS => $cache_id ) if DEBUG();
-      my $parsed = $self->_parse( $tmp, $opt->{map_keys}, $cache_id, $as_is  );
+
+      my $shared;
+      if ( $shead ) {
+         my $param = join ',', ('shift') x @sparam;
+         $shared = sprintf qq~my(%s) = (%s);~, $shead, $param;
+      }
+
+      local $self->[HEADER] = do {
+         my $old = $self->[HEADER] || '';
+         $shared . ';' . $old
+      } if $shared;
+
+      my %popt   = ( %{ $opt }, cache_id => $cache_id, as_is => $as_is );
+      my $parsed = $self->_parse( $tmp, \%popt );
       $CODE      = $self->cache->populate( $cache_id, $parsed, $opt->{chkmt} );
    }
 
-   my   @args;
-   push @args, $self if $self->[NEEDS_OBJECT];
+   my @args;
+   push @args, $self   if $self->[NEEDS_OBJECT]; # must be the first
+   push @args, @sparam if @sparam;
    push @args, @{ $self->[ADD_ARGS] } if $self->[ADD_ARGS];
    push @args, @{ $param };
    my $out = $CODE->( @args );
 
-   if ( $opt->{_filter} ) {
-      $self->_call_filters( \$out, split RE_FILTER_SPLIT, $opt->{_filter} );
-   }
+   $self->_call_filters( \$out, split RE_FILTER_SPLIT, $opt->{_filter} )
+      if $opt->{_filter};
 
    return $out;
 }
@@ -1318,12 +1375,12 @@ sub _call_filters {
    my $oref    = shift;
    my @filters = @_;
    my $fname   = $self->[FILENAME];
-   my $fbase   = 'Text::Template::Simple::Dummy';
 
    APPLY_FILTERS: foreach my $filter ( @filters ) {
-      my $fref = $fbase->can( "filter_" . $filter );
+      my $fref = DUMMY_CLASS->can( "filter_" . $filter );
       if ( ! $fref ) {
-         $$oref .= "\n[ filter warning ] Can not apply undefined filter $filter to $fname\n";
+         $$oref .= "\n[ filter warning ] Can not apply undefined filter"
+                .  " $filter to $fname\n";
          next;
       }
       $fref->( $self, $oref );
@@ -1371,7 +1428,7 @@ package Text::Template::Simple::Tokenizer;
 use strict;
 use vars qw($VERSION);
 
-$VERSION = '0.79_04';
+$VERSION = '0.79_05';
 
 use constant CMD_CHAR             =>  0;
 use constant CMD_ID               =>  1;
@@ -1409,9 +1466,10 @@ sub new {
 
 sub tokenize {
    # compile the template into a tree and optimize
-   my $self       = shift;
-   my $tmp        = shift || fatal('tts.tokenizer.tokenize.tmp');
-   my $map_keys   = shift;
+   my($self, $tmp, $map_keys) = @_;
+
+   return $self->_empty_token( $tmp ) if ! $tmp;
+   
    my($ds, $de)   = ($self->[ID_DS], $self->[ID_DE]);
    my($qds, $qde) = map { quotemeta $_ } $ds, $de;
 
@@ -1449,41 +1507,26 @@ sub tokenize {
 sub tilde { shift; Text::Template::Simple::Util::escape( '~' => @_ ) }
 sub quote { shift; Text::Template::Simple::Util::escape( '"' => @_ ) }
 
-sub _debug_tokens {
-   my $self   = shift;
-   my $tokens = shift;
-   # TODO: heredocs look ugly
-   my $buf = <<'HEAD';
+sub _empty_token {
+   my $self = shift;
+   my $tmp  = shift;
+   fatal('tts.tokenizer.tokenize.tmp') if ! defined $tmp;
+   # empty string or zero
+   return [
+         [ $self->[ID_DS], T_DELIMSTART, [], undef ],
+         [ $tmp          , T_RAW       , [], undef ],
+         [ $self->[ID_DE], T_DELIMEND  , [], undef ],
+   ]
+}
 
----------------------------
-       TOKEN DUMP
----------------------------
-HEAD
-
-   my $tmp = <<'DUMP';
-ID        : %s
-STRING    : %s
-CHOMP_NEXT: %s
-CHOMP_PREV: %s
-TRIGGER   : %s
----------------------------
-DUMP
-
-   foreach my $t ( @{ $tokens } ) {
-      my $s = $t->[TOKEN_STR];
-      $s =~ s{\r}{\\r}xmsg;
-      $s =~ s{\n}{\\n}xmsg;
-      $s =~ s{\f}{\\f}xmsg;
-      $s =~ s{\s}{\\s}xmsg;
-      my @v = (
-         scalar $self->_visualize_chomp( $t->[TOKEN_CHOMP][TOKEN_CHOMP_NEXT] ),
-         scalar $self->_visualize_chomp( $t->[TOKEN_CHOMP][TOKEN_CHOMP_PREV] ),
-         scalar $self->_visualize_chomp( $t->[TOKEN_TRIGGER]                 )
-      );
-      @v = map { $_ eq 'undef' ? '' : $_ } @v;
-      $buf .= sprintf $tmp, $self->_visualize_tid( $t->[TOKEN_ID] ), $s, @v;
-   }
-   Text::Template::Simple::Util::LOG( DEBUG => $buf );
+sub _get_command_chars {
+   my($self, $str) = @_;
+   my($first, $second, $last) = ('') x 3;
+   # $first is the left-cmd, $last is the right-cmd. $second is the extra
+   $first  = substr $str, SUBSTR_OFFSET_FIRST , SUBSTR_LENGTH if $str ne '';
+   $second = substr $str, SUBSTR_OFFSET_SECOND, SUBSTR_LENGTH if $str ne '';
+   $last   = substr $str, length($str) - 1    , SUBSTR_LENGTH if $str ne '';
+   return $first, $second, $last;
 }
 
 sub _user_commands {
@@ -1538,16 +1581,6 @@ sub _token_for_code {
             ];
 }
 
-sub _get_command_chars {
-   my($self, $str) = @_;
-   my($first, $second, $last) = ('') x 3;
-   # $first is the left-cmd, $last is the right-cmd. $second is the extra
-   $first  = substr $str, SUBSTR_OFFSET_FIRST , SUBSTR_LENGTH if $str ne '';
-   $second = substr $str, SUBSTR_OFFSET_SECOND, SUBSTR_LENGTH if $str ne '';
-   $last   = substr $str, length($str) - 1    , SUBSTR_LENGTH if $str ne '';
-   return $first, $second, $last;
-}
-
 sub _token_code {
    my($self, $str, $inside, $map_keys, $tree) = @_;
    my($first, $second, $last) = $self->_get_command_chars( $str );
@@ -1682,6 +1715,43 @@ sub _visualize_tid {
    return $rv;
 }
 
+sub _debug_tokens {
+   my $self   = shift;
+   my $tokens = shift;
+   # TODO: heredocs look ugly
+   my $buf = <<'HEAD';
+
+---------------------------
+       TOKEN DUMP
+---------------------------
+HEAD
+
+   my $tmp = <<'DUMP';
+ID        : %s
+STRING    : %s
+CHOMP_NEXT: %s
+CHOMP_PREV: %s
+TRIGGER   : %s
+---------------------------
+DUMP
+
+   foreach my $t ( @{ $tokens } ) {
+      my $s = $t->[TOKEN_STR];
+      $s =~ s{\r}{\\r}xmsg;
+      $s =~ s{\n}{\\n}xmsg;
+      $s =~ s{\f}{\\f}xmsg;
+      $s =~ s{\s}{\\s}xmsg;
+      my @v = (
+         scalar $self->_visualize_chomp( $t->[TOKEN_CHOMP][TOKEN_CHOMP_NEXT] ),
+         scalar $self->_visualize_chomp( $t->[TOKEN_CHOMP][TOKEN_CHOMP_PREV] ),
+         scalar $self->_visualize_chomp( $t->[TOKEN_TRIGGER]                 )
+      );
+      @v = map { $_ eq 'undef' ? '' : $_ } @v;
+      $buf .= sprintf $tmp, $self->_visualize_tid( $t->[TOKEN_ID] ), $s, @v;
+   }
+   Text::Template::Simple::Util::LOG( DEBUG => $buf );
+}
+
 sub DESTROY {
    my $self = shift || return;
    LOG( DESTROY => ref $self ) if DEBUG();
@@ -1698,7 +1768,7 @@ use constant MY_IO_LAYER      => 0;
 use constant MY_INCLUDE_PATHS => 1;
 use constant MY_TAINT_MODE    => 2;
 
-$VERSION = '0.79_04';
+$VERSION = '0.79_05';
 
 sub new {
    my $class = shift;
@@ -1787,7 +1857,7 @@ sub slurp {
 }
 
 sub _handle_looks_safe {
-   # Cargo Culting: original code was taken from "The Camel"
+   # Cargo Culting: original taint checking code was taken from "The Camel"
    my $self = shift;
    my $fh   = shift;
    fatal('tts.io.hls.invalid') if ! $fh || ! fileno $fh;
@@ -1804,7 +1874,7 @@ sub _handle_looks_safe {
 
    # Check whether group or other can write file.
    # Read check is disabled by default
-   # Mode always 0666 on Windows, so all tests below are disabled on Windows
+   # Mode is always 0666 on Windows, so all tests below are disabled on Windows
    # unless you force them to run
    LOG( FILE_MODE => sprintf "%04o", $i->mode & 07777) if DEBUG;
 
@@ -1878,7 +1948,7 @@ use vars qw($VERSION);
 use Text::Template::Simple::Caller;
 use Text::Template::Simple::Util qw();
 
-$VERSION = '0.79_04';
+$VERSION = '0.79_05';
 
 sub stack { # just a wrapper
    my $opt = shift || {};
@@ -1894,7 +1964,7 @@ use strict;
 use vars qw($VERSION);
 use Text::Template::Simple::Dummy;
 
-$VERSION = '0.79_04';
+$VERSION = '0.79_05';
 
 sub _compile { shift; return eval shift }
 
@@ -1913,7 +1983,7 @@ use constant HINTS      => 8;
 use constant BITMASK    => 9;
 use Text::Template::Simple::Util qw( ishref fatal );
 
-$VERSION = '0.79_04';
+$VERSION = '0.79_05';
 
 sub stack {
    my $self    = shift;
@@ -2086,7 +2156,7 @@ use Text::Template::Simple::Constants qw(:all);
 use Text::Template::Simple::Util qw( DEBUG LOG ishref fatal );
 use Carp qw( croak );
 
-$VERSION = '0.79_04';
+$VERSION = '0.79_05';
 
 my $CACHE = {}; # in-memory template cache
 
@@ -2500,7 +2570,7 @@ package Text::Template::Simple;
 use strict;
 use vars qw($VERSION);
 
-$VERSION = '0.79_04';
+$VERSION = '0.79_05';
 
 use File::Spec;
 use Text::Template::Simple::Constants qw(:all);
@@ -2588,7 +2658,7 @@ sub new {
    my($fid, $fval);
    INITIALIZE: foreach my $field ( keys %DEFAULT ) {
       $fid = uc $field;
-      next INITIALIZE if ! $class->can($fid);
+      next INITIALIZE if ! $class->can( $fid );
       $fid  = $class->$fid();
       $fval = delete $param{$field};
       $self->[$fid] = defined $fval ? $fval : $DEFAULT{$field};
@@ -2641,7 +2711,7 @@ sub _init {
    $self->[FAKER_HASH]     = $self->_output_buffer_var('hash');
    $self->[FAKER_SELF]     = $self->_output_buffer_var('self');
    $self->[INSIDE_INCLUDE] = -1; # must be -1 not 0
-   $self->[NEEDS_OBJECT]   =  0; # does the template need $self ?
+   $self->[NEEDS_OBJECT]   =  0; # the template needs $self ?
    $self->[DEEP_RECURSION] =  0; # recursion detector
 
    fatal('tts.main.init.thandler')
@@ -2762,8 +2832,8 @@ generated with an automatic build tool. If you experience problems
 with this version, please install and use the supported standard
 version. This version is B<NOT SUPPORTED>.
 
-This document describes version C<0.79_04> of C<Text::Template::Simple>
-released on C<3 May 2009>.
+This document describes version C<0.79_05> of C<Text::Template::Simple>
+released on C<2 August 2009>.
 
 B<WARNING>: This version of the module is part of a
 developer (beta) release of the distribution and it is
@@ -3013,13 +3083,19 @@ PARAM
 
 FILTER
 
+=item *
+
+SHARE
+
 =back
 
    <%+ /path/to/static.tts  | FILTER: MyFilter %>
    <%* /path/to/dynamic.tts | FILTER: MyFilter | PARAM: test => 123 %>
 
-C<FILTER:> defines the list of filters to apply to the output of the include.
 C<PARAM:> defines the parameter list to pass to the included file.
+C<FILTER:> defines the list of filters to apply to the output of the include.
+C<SHARE:> used to list the variables to share with the included template when
+the monolith option is disabled.
 
 =head3 INCLUDE FILTERS
 
@@ -3059,6 +3135,37 @@ A block consists of a header part and the content.
 C<HEADER> includes the commands and terminated with a semicolon. C<BODY> is the
 actual block content.
 
+=head3 SHARED VARIABLES
+
+C<Text::Template::Simple> compiles every template individually with separate
+scopes. A variable defined in the master template is not accessible from a
+dynamic include. The exception to this rule is the C<monolith> option to C<new>.
+If it is enabled; the master template and any includes it has will be compiled
+into a single document, thus making every variable defined at the top available
+to the includes below. But this method has a drawback, it disables cache check
+for the sub files (includes). You'll need to edit the master template to force
+a cache reload.
+
+If you don't use C<monolith> (disabled by default), then you'll need to share
+the variables somehow to don't repeat yourself. Variable sharing is demonstrated
+in the below template:
+
+   <%
+      my $foo = 42;
+      my $bar = 23;
+   %>
+   <%* dyna.inc | SHARE: $foo, $bar %>
+
+And then you can access C<$foo> and C<$bar> inside C<dyna.inc>. There is one
+drawback by shared variables: only SCALARs can be shared. You can not share
+anything else. If you want to share an array, use an array reference instead:
+
+   <%
+      my @foo = (1..10);
+      my $fooref = \@foo;
+   %>
+   <%* dyna.inc | SHARE: $fooref %>
+
 =head3 BLOCK FILTERS
 
 B<WARNING> Block filters are considered to be experimental. They may be changed
@@ -3149,16 +3256,16 @@ However, be aware that the monolithic version is B<not supported>.
 
 =head1 AUTHOR
 
-Burak GE<252>rsoy, E<lt>burakE<64>cpan.orgE<gt>
+Burak Gursoy <burak@cpan.org>.
 
 =head1 COPYRIGHT
 
-Copyright 2004-2009 Burak GE<252>rsoy. All rights reserved.
+Copyright 2004 - 2009 Burak Gursoy. All rights reserved.
 
 =head1 LICENSE
 
 This library is free software; you can redistribute it and/or modify 
-it under the same terms as Perl itself, either Perl version 5.8.8 or, 
+it under the same terms as Perl itself, either Perl version 5.10.0 or, 
 at your option, any later version of Perl 5 you may have available.
 
 =cut
